# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: toi.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ttoi.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x01\n\x07\x43\x61\x64\x65nce\x12-\n\tfrequency\x18\x01 \x01(\x0e\x32\x1a.oi.papi.Cadence.Frequency\x12\r\n\x05value\x18\x02 \x01(\r\"l\n\tFrequency\x12\x15\n\x11UNKNOWN_FREQUENCY\x10\x00\x12\x0c\n\x08MINUTELY\x10\x01\x12\n\n\x06HOURLY\x10\x02\x12\t\n\x05\x44\x41ILY\x10\x03\x12\n\n\x06WEEKLY\x10\x04\x12\x0b\n\x07MONTHLY\x10\x05\x12\n\n\x06YEARLY\x10\x06\"J\n\nRecurrence\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04rule\x18\x02 \x01(\t\x12\"\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x10.oi.papi.Cadence\"\xe6\x01\n\x03TOI\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x0bstart_local\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x66inish_local\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x0brecurrences\x18\x04 \x03(\x0b\x32\x13.oi.papi.Recurrence\x12\x31\n\rexclude_dates\x18\x05 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\xe7\x01\n\x10TOICreateRequest\x12/\n\x0bstart_local\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x66inish_local\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x0brecurrences\x18\x03 \x03(\x0b\x32\x13.oi.papi.Recurrence\x12\x31\n\rexclude_dates\x18\x04 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"C\n\x11TOICreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x19\n\x03toi\x18\x02 \x01(\x0b\x32\x0c.oi.papi.TOI\"\x1f\n\x10TOIDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"(\n\x11TOIDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"E\n\rTOIGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"q\n\x0eTOIGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x0btoi_objects\x18\x02 \x03(\x0b\x32\x0c.oi.papi.TOI\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"N\n\x0eTOIListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"r\n\x0fTOIListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x0btoi_objects\x18\x02 \x03(\x0b\x32\x0c.oi.papi.TOI\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\xfd\x01\n\x06TOIApi\x12?\n\x06\x63reate\x12\x19.oi.papi.TOICreateRequest\x1a\x1a.oi.papi.TOICreateResponse\x12?\n\x06\x64\x65lete\x12\x19.oi.papi.TOIDeleteRequest\x1a\x1a.oi.papi.TOIDeleteResponse\x12\x36\n\x03get\x12\x16.oi.papi.TOIGetRequest\x1a\x17.oi.papi.TOIGetResponse\x12\x39\n\x04list\x12\x17.oi.papi.TOIListRequest\x1a\x18.oi.papi.TOIListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'toi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CADENCE']._serialized_start=77
  _globals['_CADENCE']._serialized_end=258
  _globals['_CADENCE_FREQUENCY']._serialized_start=150
  _globals['_CADENCE_FREQUENCY']._serialized_end=258
  _globals['_RECURRENCE']._serialized_start=260
  _globals['_RECURRENCE']._serialized_end=334
  _globals['_TOI']._serialized_start=337
  _globals['_TOI']._serialized_end=567
  _globals['_TOICREATEREQUEST']._serialized_start=570
  _globals['_TOICREATEREQUEST']._serialized_end=801
  _globals['_TOICREATERESPONSE']._serialized_start=803
  _globals['_TOICREATERESPONSE']._serialized_end=870
  _globals['_TOIDELETEREQUEST']._serialized_start=872
  _globals['_TOIDELETEREQUEST']._serialized_end=903
  _globals['_TOIDELETERESPONSE']._serialized_start=905
  _globals['_TOIDELETERESPONSE']._serialized_end=945
  _globals['_TOIGETREQUEST']._serialized_start=947
  _globals['_TOIGETREQUEST']._serialized_end=1016
  _globals['_TOIGETRESPONSE']._serialized_start=1018
  _globals['_TOIGETRESPONSE']._serialized_end=1131
  _globals['_TOILISTREQUEST']._serialized_start=1133
  _globals['_TOILISTREQUEST']._serialized_end=1211
  _globals['_TOILISTRESPONSE']._serialized_start=1213
  _globals['_TOILISTRESPONSE']._serialized_end=1327
  _globals['_TOIAPI']._serialized_start=1330
  _globals['_TOIAPI']._serialized_end=1583
# @@protoc_insertion_point(module_scope)



from . import algorithm_computation_execution_pb2_grpc as algorithm_computation_execution
from . import algorithm_computation_pb2_grpc as algorithm_computation
from . import algorithm_config_pb2_grpc as algorithm_config
from . import algorithm_manifest_pb2_grpc as algorithm_manifest
from . import algorithm_pb2_grpc as algorithm
from . import algorithm_version_pb2_grpc as algorithm_version
from . import analysis_computation_pb2_grpc as analysis_computation
from . import analysis_config_pb2_grpc as analysis_config
from . import analysis_pb2_grpc as analysis
from . import analysis_version_pb2_grpc as analysis_version
from . import aoi_catalog_pb2_grpc as aoi_catalog
from . import aoi_collection_pb2_grpc as aoi_collection
from . import aoi_export_pb2_grpc as aoi_export
from . import aoi_pb2_grpc as aoi
from . import aoi_transaction_pb2_grpc as aoi_transaction
from . import aoi_version_pb2_grpc as aoi_version
from . import common_models_pb2_grpc as common_models
from . import credit_pb2_grpc as credit
from . import data_search_pb2_grpc as data_search
from . import data_source_pb2_grpc as data_source
from . import data_type_pb2_grpc as data_type
from . import forgot_password_pb2_grpc as forgot_password
from . import imagery_pb2_grpc as imagery
from . import notification_pb2_grpc as notification
from . import permission_pb2_grpc as permission
from . import project_analysis_config_pb2_grpc as project_analysis_config
from . import project_aoi_pb2_grpc as project_aoi
from . import project_collaborator_pb2_grpc as project_collaborator
from . import project_group_pb2_grpc as project_group
from . import project_pb2_grpc as project
from . import project_result_pb2_grpc as project_result
from . import resource_pb2_grpc as resource
from . import result_pb2_grpc as result
from . import subject_pb2_grpc as subject
from . import system_pb2_grpc as system
from . import tile_pb2_grpc as tile
from . import toi_pb2_grpc as toi
from . import token_pb2_grpc as token
from . import user_collection_pb2_grpc as user_collection
from . import user_pb2_grpc as user
from . import visualization_pb2_grpc as visualization



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: project_aoi.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.aoi_pb2 import *
from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11project_aoi.proto\x12\x07oi.papi\x1a\taoi.proto\x1a\x13\x63ommon_models.proto\"e\n\x17ProjectAOICreateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61oi_ids\x18\x02 \x03(\t\x12%\n\naoi_inputs\x18\x03 \x03(\x0b\x32\x11.oi.papi.AOIInput\"X\n\x18ProjectAOICreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\x0b\x61oi_objects\x18\x02 \x03(\x0b\x32\x12.oi.papi.AOIObject\"<\n\x17ProjectAOIUploadRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\"e\n\x1cProjectAOIFileUploadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x30\n\x0f\x61oi_transaction\x18\x02 \x01(\x0b\x32\x17.oi.papi.AOITransaction\">\n\x17ProjectAOIDeleteRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61oi_ids\x18\x02 \x03(\t\"/\n\x18ProjectAOIDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"S\n\x14ProjectAOIGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"u\n\x11\x41OICollectionAOIs\x12\x19\n\x11\x61oi_collection_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61oi_collection_state\x18\x02 \x01(\t\x12\'\n\x0b\x61oi_objects\x18\x03 \x03(\x0b\x32\x12.oi.papi.AOIObject\"\x8e\x01\n\x15ProjectAOIGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x37\n\x13\x61oi_collection_aois\x18\x02 \x03(\x0b\x32\x1a.oi.papi.AOICollectionAOIs\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"p\n\x17ProjectAOIUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61oi_id\x18\x02 \x01(\t\x12\x31\n\x16\x61oi_modification_input\x18\x03 \x01(\x0b\x32\x11.oi.papi.AOIInput\"h\n\x18ProjectAOIUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x37\n\x13\x61oi_collection_aois\x18\x02 \x01(\x0b\x32\x1a.oi.papi.AOICollectionAOIs2\x97\x03\n\rProjectAOIApi\x12M\n\x06\x63reate\x12 .oi.papi.ProjectAOICreateRequest\x1a!.oi.papi.ProjectAOICreateResponse\x12S\n\x06upload\x12 .oi.papi.ProjectAOIUploadRequest\x1a%.oi.papi.ProjectAOIFileUploadResponse(\x01\x12M\n\x06\x64\x65lete\x12 .oi.papi.ProjectAOIDeleteRequest\x1a!.oi.papi.ProjectAOIDeleteResponse\x12\x44\n\x03get\x12\x1d.oi.papi.ProjectAOIGetRequest\x1a\x1e.oi.papi.ProjectAOIGetResponse\x12M\n\x06update\x12 .oi.papi.ProjectAOIUpdateRequest\x1a!.oi.papi.ProjectAOIUpdateResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_aoi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTAOICREATEREQUEST']._serialized_start=62
  _globals['_PROJECTAOICREATEREQUEST']._serialized_end=163
  _globals['_PROJECTAOICREATERESPONSE']._serialized_start=165
  _globals['_PROJECTAOICREATERESPONSE']._serialized_end=253
  _globals['_PROJECTAOIUPLOADREQUEST']._serialized_start=255
  _globals['_PROJECTAOIUPLOADREQUEST']._serialized_end=315
  _globals['_PROJECTAOIFILEUPLOADRESPONSE']._serialized_start=317
  _globals['_PROJECTAOIFILEUPLOADRESPONSE']._serialized_end=418
  _globals['_PROJECTAOIDELETEREQUEST']._serialized_start=420
  _globals['_PROJECTAOIDELETEREQUEST']._serialized_end=482
  _globals['_PROJECTAOIDELETERESPONSE']._serialized_start=484
  _globals['_PROJECTAOIDELETERESPONSE']._serialized_end=531
  _globals['_PROJECTAOIGETREQUEST']._serialized_start=533
  _globals['_PROJECTAOIGETREQUEST']._serialized_end=616
  _globals['_AOICOLLECTIONAOIS']._serialized_start=618
  _globals['_AOICOLLECTIONAOIS']._serialized_end=735
  _globals['_PROJECTAOIGETRESPONSE']._serialized_start=738
  _globals['_PROJECTAOIGETRESPONSE']._serialized_end=880
  _globals['_PROJECTAOIUPDATEREQUEST']._serialized_start=882
  _globals['_PROJECTAOIUPDATEREQUEST']._serialized_end=994
  _globals['_PROJECTAOIUPDATERESPONSE']._serialized_start=996
  _globals['_PROJECTAOIUPDATERESPONSE']._serialized_end=1100
  _globals['_PROJECTAOIAPI']._serialized_start=1103
  _globals['_PROJECTAOIAPI']._serialized_end=1510
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import algorithm_manifest_pb2 as algorithm__manifest__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in algorithm_manifest_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class AlgorithmManifestApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/oi.papi.AlgorithmManifestApi/get',
                request_serializer=algorithm__manifest__pb2.AlgorithmManifestSchemaGetRequest.SerializeToString,
                response_deserializer=algorithm__manifest__pb2.AlgorithmManifestSchemaGetResponse.FromString,
                _registered_method=True)


class AlgorithmManifestApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get(self, request, context):
        """
        Get the schema of an AlgorithmManifest, used in the creation of an AlgorithmVersion.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlgorithmManifestApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=algorithm__manifest__pb2.AlgorithmManifestSchemaGetRequest.FromString,
                    response_serializer=algorithm__manifest__pb2.AlgorithmManifestSchemaGetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AlgorithmManifestApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AlgorithmManifestApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AlgorithmManifestApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmManifestApi/get',
            algorithm__manifest__pb2.AlgorithmManifestSchemaGetRequest.SerializeToString,
            algorithm__manifest__pb2.AlgorithmManifestSchemaGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright 2017-2021 Orbital Insight Inc., all rights reserved.
# Contains confidential and trade secret information.
# Government Users:  Commercial Computer Software - Use governed by
# terms of Orbital Insight commercial license agreement.


from terrascope_api.sync_client import TerrascopeSyncClient  # noqa
from terrascope_api.async_client import TerrascopeAsyncClient  # noqa



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_type.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x61ta_type.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\"\x9a\x01\n\x08\x44\x61taType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x04 \x03(\t\x12\x13\n\x0bsensor_type\x18\x05 \x01(\t\x12-\n\x0cquery_schema\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x8e\x01\n\x15\x44\x61taTypeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x13\n\x0bsensor_type\x18\x04 \x01(\t\x12-\n\x0cquery_schema\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"S\n\x16\x44\x61taTypeCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\tdata_type\x18\x02 \x01(\x0b\x32\x11.oi.papi.DataType\"#\n\x12\x44\x61taTypeGetRequest\x12\r\n\x05names\x18\x01 \x03(\t\"Q\n\x13\x44\x61taTypeGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\ndata_types\x18\x02 \x03(\x0b\x32\x11.oi.papi.DataType\"*\n\x13\x44\x61taTypeListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"R\n\x14\x44\x61taTypeListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\ndata_types\x18\x02 \x03(\x0b\x32\x11.oi.papi.DataType2\xdf\x01\n\x0b\x44\x61taTypeAPI\x12I\n\x06\x63reate\x12\x1e.oi.papi.DataTypeCreateRequest\x1a\x1f.oi.papi.DataTypeCreateResponse\x12@\n\x03get\x12\x1b.oi.papi.DataTypeGetRequest\x1a\x1c.oi.papi.DataTypeGetResponse\x12\x43\n\x04list\x12\x1c.oi.papi.DataTypeListRequest\x1a\x1d.oi.papi.DataTypeListResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATATYPE']._serialized_start=59
  _globals['_DATATYPE']._serialized_end=213
  _globals['_DATATYPECREATEREQUEST']._serialized_start=216
  _globals['_DATATYPECREATEREQUEST']._serialized_end=358
  _globals['_DATATYPECREATERESPONSE']._serialized_start=360
  _globals['_DATATYPECREATERESPONSE']._serialized_end=443
  _globals['_DATATYPEGETREQUEST']._serialized_start=445
  _globals['_DATATYPEGETREQUEST']._serialized_end=480
  _globals['_DATATYPEGETRESPONSE']._serialized_start=482
  _globals['_DATATYPEGETRESPONSE']._serialized_end=563
  _globals['_DATATYPELISTREQUEST']._serialized_start=565
  _globals['_DATATYPELISTREQUEST']._serialized_end=607
  _globals['_DATATYPELISTRESPONSE']._serialized_start=609
  _globals['_DATATYPELISTRESPONSE']._serialized_end=691
  _globals['_DATATYPEAPI']._serialized_start=694
  _globals['_DATATYPEAPI']._serialized_end=917
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import analysis_version_pb2 as analysis__version__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in analysis_version_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class AnalysisVersionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AnalysisVersionApi/create',
                request_serializer=analysis__version__pb2.AnalysisVersionCreateRequest.SerializeToString,
                response_deserializer=analysis__version__pb2.AnalysisVersionCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AnalysisVersionApi/get',
                request_serializer=analysis__version__pb2.AnalysisVersionGetRequest.SerializeToString,
                response_deserializer=analysis__version__pb2.AnalysisVersionGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.AnalysisVersionApi/list',
                request_serializer=analysis__version__pb2.AnalysisVersionListRequest.SerializeToString,
                response_deserializer=analysis__version__pb2.AnalysisVersionListResponse.FromString,
                _registered_method=True)


class AnalysisVersionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Given a top level Analysis, create a new version, which must be semantically greater than the previously created version.
        Once an AnalysisVersion has been created, it is immutable. Any changes require a new version to be created.
        The purpose of this is to either upgrade the structure of the Analysis DAG OR update the versions of the algorithms assigned to the Analysis.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the details for a specific AnalysisVersion. By default it does not include the analysis_manifest.
        Setting include_manifest to true, will also include the manifest in the response for each requested AnalysisVersion.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List all the AnalysisVersions that the user has access to.
        Search text will be applied to the entire manifest returning all AnalysisVersions whose manifest contains the search text.
        Tags will be matched exactly with the tags on the manifest.
        By default, this method only returns the semantically latest version of each Analysis that has not been deprecated.
        It does not include manifests in the response.
        If include_all_versions is set to true, all prior versions of an Analysis including deprecated AnalysisVersions will be returned, as well.
        If include_manifest is set to true, the corresponding manifest of each AnalysisVersion will also be returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalysisVersionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=analysis__version__pb2.AnalysisVersionCreateRequest.FromString,
                    response_serializer=analysis__version__pb2.AnalysisVersionCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=analysis__version__pb2.AnalysisVersionGetRequest.FromString,
                    response_serializer=analysis__version__pb2.AnalysisVersionGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=analysis__version__pb2.AnalysisVersionListRequest.FromString,
                    response_serializer=analysis__version__pb2.AnalysisVersionListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AnalysisVersionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AnalysisVersionApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AnalysisVersionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisVersionApi/create',
            analysis__version__pb2.AnalysisVersionCreateRequest.SerializeToString,
            analysis__version__pb2.AnalysisVersionCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisVersionApi/get',
            analysis__version__pb2.AnalysisVersionGetRequest.SerializeToString,
            analysis__version__pb2.AnalysisVersionGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisVersionApi/list',
            analysis__version__pb2.AnalysisVersionListRequest.SerializeToString,
            analysis__version__pb2.AnalysisVersionListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common_models.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon_models.proto\x12\x07oi.papi\"L\n\nPagination\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_models_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PAGINATION']._serialized_start=32
  _globals['_PAGINATION']._serialized_end=108
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import project_result_pb2 as project__result__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in project_result_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ProjectResultApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_filter_mapping = channel.unary_unary(
                '/oi.papi.ProjectResultApi/create_filter_mapping',
                request_serializer=project__result__pb2.ProjectResultFilterMappingCreateRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultFilterMappingCreateResponse.FromString,
                _registered_method=True)
        self.delete_filter_mapping = channel.unary_unary(
                '/oi.papi.ProjectResultApi/delete_filter_mapping',
                request_serializer=project__result__pb2.ProjectResultFilterMappingDeleteRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultFilterMappingDeleteResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.ProjectResultApi/get',
                request_serializer=project__result__pb2.ProjectResultGetRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGetResponse.FromString,
                _registered_method=True)
        self.get_status = channel.unary_unary(
                '/oi.papi.ProjectResultApi/get_status',
                request_serializer=project__result__pb2.ProjectResultGetStatusRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGetStatusResponse.FromString,
                _registered_method=True)
        self.get_download = channel.unary_unary(
                '/oi.papi.ProjectResultApi/get_download',
                request_serializer=project__result__pb2.ProjectResultGetDownloadRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGetDownloadResponse.FromString,
                _registered_method=True)
        self.generate_download = channel.unary_unary(
                '/oi.papi.ProjectResultApi/generate_download',
                request_serializer=project__result__pb2.ProjectResultGenerateDownloadRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGenerateDownloadResponse.FromString,
                _registered_method=True)


class ProjectResultApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_filter_mapping(self, request, context):
        """
        Create a project result filter mapping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_filter_mapping(self, request, context):
        """
        Delete a project result filter mapping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get Project Results
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_status(self, request, context):
        """
        Get Project Result Status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_download(self, request, context):
        """
        Get Project Result Download
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def generate_download(self, request, context):
        """
        Generate Project Result Download
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectResultApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_filter_mapping': grpc.unary_unary_rpc_method_handler(
                    servicer.create_filter_mapping,
                    request_deserializer=project__result__pb2.ProjectResultFilterMappingCreateRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultFilterMappingCreateResponse.SerializeToString,
            ),
            'delete_filter_mapping': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_filter_mapping,
                    request_deserializer=project__result__pb2.ProjectResultFilterMappingDeleteRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultFilterMappingDeleteResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=project__result__pb2.ProjectResultGetRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGetResponse.SerializeToString,
            ),
            'get_status': grpc.unary_unary_rpc_method_handler(
                    servicer.get_status,
                    request_deserializer=project__result__pb2.ProjectResultGetStatusRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGetStatusResponse.SerializeToString,
            ),
            'get_download': grpc.unary_unary_rpc_method_handler(
                    servicer.get_download,
                    request_deserializer=project__result__pb2.ProjectResultGetDownloadRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGetDownloadResponse.SerializeToString,
            ),
            'generate_download': grpc.unary_unary_rpc_method_handler(
                    servicer.generate_download,
                    request_deserializer=project__result__pb2.ProjectResultGenerateDownloadRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGenerateDownloadResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.ProjectResultApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.ProjectResultApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectResultApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_filter_mapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/create_filter_mapping',
            project__result__pb2.ProjectResultFilterMappingCreateRequest.SerializeToString,
            project__result__pb2.ProjectResultFilterMappingCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete_filter_mapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/delete_filter_mapping',
            project__result__pb2.ProjectResultFilterMappingDeleteRequest.SerializeToString,
            project__result__pb2.ProjectResultFilterMappingDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/get',
            project__result__pb2.ProjectResultGetRequest.SerializeToString,
            project__result__pb2.ProjectResultGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/get_status',
            project__result__pb2.ProjectResultGetStatusRequest.SerializeToString,
            project__result__pb2.ProjectResultGetStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/get_download',
            project__result__pb2.ProjectResultGetDownloadRequest.SerializeToString,
            project__result__pb2.ProjectResultGetDownloadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def generate_download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/generate_download',
            project__result__pb2.ProjectResultGenerateDownloadRequest.SerializeToString,
            project__result__pb2.ProjectResultGenerateDownloadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tile.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntile.proto\x12\x0coi.papi.tile\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"D\n\x06\x42ounds\x12\r\n\x05x_min\x18\x01 \x01(\x02\x12\r\n\x05y_min\x18\x02 \x01(\x02\x12\r\n\x05x_max\x18\x03 \x01(\x02\x12\r\n\x05y_max\x18\x04 \x01(\x02\"&\n\nTileMatrix\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04zoom\x18\x02 \x01(\x05\"T\n\x0eTileAccessInfo\x12\x14\n\x0curl_template\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xd5\x01\n\x07TileSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x06\x62ounds\x18\x03 \x01(\x0b\x32\x14.oi.papi.tile.Bounds\x12*\n\x08matrices\x18\x04 \x03(\x0b\x32\x18.oi.papi.tile.TileMatrix\x12\x31\n\x0btile_access\x18\x05 \x01(\x0b\x32\x1c.oi.papi.tile.TileAccessInfo\x12+\n\x07\x66rom_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb2\x01\n\x12TileSetListRequest\x12\x11\n\tsearch_id\x18\x01 \x01(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x30\n\x0ctile_ts_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ntile_ts_to\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"h\n\x13TileSetListResponse\x12(\n\ttile_sets\x18\x01 \x03(\x0b\x32\x15.oi.papi.tile.TileSet\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination2V\n\x07TileApi\x12K\n\x04list\x12 .oi.papi.tile.TileSetListRequest\x1a!.oi.papi.tile.TileSetListResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BOUNDS']._serialized_start=112
  _globals['_BOUNDS']._serialized_end=180
  _globals['_TILEMATRIX']._serialized_start=182
  _globals['_TILEMATRIX']._serialized_end=220
  _globals['_TILEACCESSINFO']._serialized_start=222
  _globals['_TILEACCESSINFO']._serialized_end=306
  _globals['_TILESET']._serialized_start=309
  _globals['_TILESET']._serialized_end=522
  _globals['_TILESETLISTREQUEST']._serialized_start=525
  _globals['_TILESETLISTREQUEST']._serialized_end=703
  _globals['_TILESETLISTRESPONSE']._serialized_start=705
  _globals['_TILESETLISTRESPONSE']._serialized_end=809
  _globals['_TILEAPI']._serialized_start=811
  _globals['_TILEAPI']._serialized_end=897
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: project_group.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import project_pb2 as project__pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__config__pb2 = project__pb2.analysis__config__pb2
except AttributeError:
  analysis__config__pb2 = project__pb2.analysis_config_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__version__pb2 = project__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = project__pb2.analysis_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__version__pb2 = project__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = project__pb2.algorithm_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__config__pb2 = project__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = project__pb2.algorithm_config_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__version__pb2 = project__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = project__pb2.algorithm_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__computation__pb2 = project__pb2.analysis__computation__pb2
except AttributeError:
  analysis__computation__pb2 = project__pb2.analysis_computation_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  aoi__collection__pb2 = project__pb2.aoi__collection__pb2
except AttributeError:
  aoi__collection__pb2 = project__pb2.aoi_collection_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  result__pb2 = project__pb2.result__pb2
except AttributeError:
  result__pb2 = project__pb2.result_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  toi__pb2 = project__pb2.toi__pb2
except AttributeError:
  toi__pb2 = project__pb2.toi_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  project__result__pb2 = project__pb2.project__result__pb2
except AttributeError:
  project__result__pb2 = project__pb2.project_result_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  result__pb2 = project__pb2.result__pb2
except AttributeError:
  result__pb2 = project__pb2.result_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  toi__pb2 = project__pb2.toi__pb2
except AttributeError:
  toi__pb2 = project__pb2.toi_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__config__pb2 = project__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = project__pb2.algorithm_config_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__version__pb2 = project__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = project__pb2.algorithm_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  visualization__pb2 = project__pb2.visualization__pb2
except AttributeError:
  visualization__pb2 = project__pb2.visualization_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.project_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13project_group.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\rproject.proto\"s\n\x0cProjectGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x08projects\x18\x03 \x03(\x0b\x32\x10.oi.papi.Project\x12\x11\n\tcollapsed\x18\x04 \x01(\x08\x12\x12\n\nsort_order\x18\x05 \x01(\r\"B\n\x17ProjectGroupListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x87\x01\n\x18ProjectGroupListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12-\n\x0eproject_groups\x18\x02 \x03(\x0b\x32\x15.oi.papi.ProjectGroup\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\">\n\x19ProjectGroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bproject_ids\x18\x02 \x03(\t\"_\n\x1aProjectGroupCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\rproject_group\x18\x02 \x01(\x0b\x32\x15.oi.papi.ProjectGroup\"(\n\x19ProjectGroupDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aProjectGroupDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"{\n\x19ProjectGroupUpdateRequest\x12-\n\x0eproject_groups\x18\x01 \x03(\x0b\x32\x15.oi.papi.ProjectGroup\x12\x17\n\x0fupdate_projects\x18\x02 \x01(\x08\x12\x16\n\x0eupdate_details\x18\x03 \x01(\x08\"1\n\x1aProjectGroupUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xd7\x02\n\x0fProjectGroupApi\x12K\n\x04list\x12 .oi.papi.ProjectGroupListRequest\x1a!.oi.papi.ProjectGroupListResponse\x12Q\n\x06\x63reate\x12\".oi.papi.ProjectGroupCreateRequest\x1a#.oi.papi.ProjectGroupCreateResponse\x12Q\n\x06\x64\x65lete\x12\".oi.papi.ProjectGroupDeleteRequest\x1a#.oi.papi.ProjectGroupDeleteResponse\x12Q\n\x06update\x12\".oi.papi.ProjectGroupUpdateRequest\x1a#.oi.papi.ProjectGroupUpdateResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTGROUP']._serialized_start=68
  _globals['_PROJECTGROUP']._serialized_end=183
  _globals['_PROJECTGROUPLISTREQUEST']._serialized_start=185
  _globals['_PROJECTGROUPLISTREQUEST']._serialized_end=251
  _globals['_PROJECTGROUPLISTRESPONSE']._serialized_start=254
  _globals['_PROJECTGROUPLISTRESPONSE']._serialized_end=389
  _globals['_PROJECTGROUPCREATEREQUEST']._serialized_start=391
  _globals['_PROJECTGROUPCREATEREQUEST']._serialized_end=453
  _globals['_PROJECTGROUPCREATERESPONSE']._serialized_start=455
  _globals['_PROJECTGROUPCREATERESPONSE']._serialized_end=550
  _globals['_PROJECTGROUPDELETEREQUEST']._serialized_start=552
  _globals['_PROJECTGROUPDELETEREQUEST']._serialized_end=592
  _globals['_PROJECTGROUPDELETERESPONSE']._serialized_start=594
  _globals['_PROJECTGROUPDELETERESPONSE']._serialized_end=643
  _globals['_PROJECTGROUPUPDATEREQUEST']._serialized_start=645
  _globals['_PROJECTGROUPUPDATEREQUEST']._serialized_end=768
  _globals['_PROJECTGROUPUPDATERESPONSE']._serialized_start=770
  _globals['_PROJECTGROUPUPDATERESPONSE']._serialized_end=819
  _globals['_PROJECTGROUPAPI']._serialized_start=822
  _globals['_PROJECTGROUPAPI']._serialized_end=1165
# @@protoc_insertion_point(module_scope)



import aoi_pb2 as _aoi_pb2
import common_models_pb2 as _common_models_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from aoi_pb2 import AOITransaction as AOITransaction
from aoi_pb2 import AOIIdentifier as AOIIdentifier
from aoi_pb2 import AOIObject as AOIObject
from aoi_pb2 import AOIVersion as AOIVersion
from aoi_pb2 import AOIInput as AOIInput
from aoi_pb2 import AOICreateRequest as AOICreateRequest
from aoi_pb2 import AOICreateResponse as AOICreateResponse
from aoi_pb2 import AOIUploadRequest as AOIUploadRequest
from aoi_pb2 import AOIUploadResponse as AOIUploadResponse
from aoi_pb2 import AOIGetRequest as AOIGetRequest
from aoi_pb2 import AOIGetResponse as AOIGetResponse
from aoi_pb2 import AOIUpdateRequest as AOIUpdateRequest
from aoi_pb2 import AOIUpdateResponse as AOIUpdateResponse
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectAOICreateRequest(_message.Message):
    __slots__ = ("project_id", "aoi_ids", "aoi_inputs")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_IDS_FIELD_NUMBER: _ClassVar[int]
    AOI_INPUTS_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    aoi_ids: _containers.RepeatedScalarFieldContainer[str]
    aoi_inputs: _containers.RepeatedCompositeFieldContainer[_aoi_pb2.AOIInput]
    def __init__(self, project_id: _Optional[str] = ..., aoi_ids: _Optional[_Iterable[str]] = ..., aoi_inputs: _Optional[_Iterable[_Union[_aoi_pb2.AOIInput, _Mapping]]] = ...) -> None: ...

class ProjectAOICreateResponse(_message.Message):
    __slots__ = ("status_code", "aoi_objects")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_objects: _containers.RepeatedCompositeFieldContainer[_aoi_pb2.AOIObject]
    def __init__(self, status_code: _Optional[int] = ..., aoi_objects: _Optional[_Iterable[_Union[_aoi_pb2.AOIObject, _Mapping]]] = ...) -> None: ...

class ProjectAOIUploadRequest(_message.Message):
    __slots__ = ("project_id", "chunk")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    chunk: bytes
    def __init__(self, project_id: _Optional[str] = ..., chunk: _Optional[bytes] = ...) -> None: ...

class ProjectAOIFileUploadResponse(_message.Message):
    __slots__ = ("status_code", "aoi_transaction")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_transaction: _aoi_pb2.AOITransaction
    def __init__(self, status_code: _Optional[int] = ..., aoi_transaction: _Optional[_Union[_aoi_pb2.AOITransaction, _Mapping]] = ...) -> None: ...

class ProjectAOIDeleteRequest(_message.Message):
    __slots__ = ("project_id", "aoi_ids")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_IDS_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    aoi_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, project_id: _Optional[str] = ..., aoi_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectAOIDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectAOIGetRequest(_message.Message):
    __slots__ = ("project_id", "pagination")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, project_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AOICollectionAOIs(_message.Message):
    __slots__ = ("aoi_collection_id", "aoi_collection_state", "aoi_objects")
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_STATE_FIELD_NUMBER: _ClassVar[int]
    AOI_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    aoi_collection_id: str
    aoi_collection_state: str
    aoi_objects: _containers.RepeatedCompositeFieldContainer[_aoi_pb2.AOIObject]
    def __init__(self, aoi_collection_id: _Optional[str] = ..., aoi_collection_state: _Optional[str] = ..., aoi_objects: _Optional[_Iterable[_Union[_aoi_pb2.AOIObject, _Mapping]]] = ...) -> None: ...

class ProjectAOIGetResponse(_message.Message):
    __slots__ = ("status_code", "aoi_collection_aois", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_AOIS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_collection_aois: _containers.RepeatedCompositeFieldContainer[AOICollectionAOIs]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., aoi_collection_aois: _Optional[_Iterable[_Union[AOICollectionAOIs, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class ProjectAOIUpdateRequest(_message.Message):
    __slots__ = ("project_id", "aoi_id", "aoi_modification_input")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_MODIFICATION_INPUT_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    aoi_id: str
    aoi_modification_input: _aoi_pb2.AOIInput
    def __init__(self, project_id: _Optional[str] = ..., aoi_id: _Optional[str] = ..., aoi_modification_input: _Optional[_Union[_aoi_pb2.AOIInput, _Mapping]] = ...) -> None: ...

class ProjectAOIUpdateResponse(_message.Message):
    __slots__ = ("status_code", "aoi_collection_aois")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_AOIS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_collection_aois: AOICollectionAOIs
    def __init__(self, status_code: _Optional[int] = ..., aoi_collection_aois: _Optional[_Union[AOICollectionAOIs, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: credit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63redit.proto\x12\x0eoi.papi.credit\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"E\n\x10\x43reditAddRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0e\n\x06reason\x18\x03 \x01(\t\"(\n\x11\x43reditAddResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n\x13\x43reditRemoveRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0e\n\x06reason\x18\x03 \x01(\t\"+\n\x14\x43reditRemoveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n\x13\x43reditRefundRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0e\n\x06reason\x18\x03 \x01(\t\"+\n\x14\x43reditRefundResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x85\x01\n#CreditAlgorithmMultiplierSetRequest\x12\x1c\n\x14\x61lgorithm_version_id\x18\x01 \x01(\t\x12!\n\x19\x61lgorithm_execution_price\x18\x02 \x01(\x01\x12\x1d\n\x15\x61lgorithm_value_price\x18\x03 \x01(\x01\";\n$CreditAlgorithmMultiplierSetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"Y\n$CreditDataSourceMultiplierSetRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x19\n\x11\x64\x61ta_source_price\x18\x02 \x01(\x01\"<\n%CreditDataSourceMultiplierSetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xd9\x02\n\x15\x43reditEstimateRequest\x12 \n\x18\x61lgorithm_computation_id\x18\x01 \x01(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x02 \x03(\t\x12S\n\x12\x61nalysis_resources\x18\x03 \x01(\x0b\x32\x37.oi.papi.credit.CreditEstimateRequest.AnalysisResources\x1a\xa6\x01\n\x11\x41nalysisResources\x12\x1a\n\x12\x61oi_collection_ids\x18\x01 \x03(\t\x12\x1b\n\x13\x61nalysis_config_ids\x18\x02 \x03(\t\x12,\n\x08start_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"S\n\x16\x43reditEstimateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x17\n\x0f\x63redit_estimate\x18\x02 \x01(\x01\x12\x0b\n\x03msg\x18\x03 \x01(\t\"N\n\x06\x43redit\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x11\n\tavailable\x18\x02 \x01(\x01\x12\x10\n\x08reserved\x18\x03 \x01(\x01\x12\x0c\n\x04used\x18\x04 \x01(\x01\")\n\x14\x43reditSummaryRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\"T\n\x15\x43reditSummaryResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\x06\x63redit\x18\x02 \x01(\x0b\x32\x16.oi.papi.credit.Credit\"\xc2\x03\n\x0bTransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10\x63redit_source_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x45\n\x10transaction_type\x18\x04 \x01(\x0e\x32+.oi.papi.credit.Transaction.TransactionType\x12\x0e\n\x06\x61mount\x18\x05 \x01(\x01\x12\x0e\n\x06reason\x18\x06 \x01(\t\x12\x31\n\rtransacted_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x63redit_available\x18\x08 \x01(\x01\x12\x17\n\x0f\x63redit_reserved\x18\t \x01(\x01\x12\x13\n\x0b\x63redit_used\x18\n \x01(\x01\x12 \n\x18\x61lgorithm_computation_id\x18\x0b \x01(\t\"x\n\x0fTransactionType\x12\x1c\n\x18UNKNOWN_TRANSACTION_TYPE\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x12\n\n\x06REFUND\x10\x03\x12\x0b\n\x07RESERVE\x10\x04\x12\r\n\tUNRESERVE\x10\x05\x12\n\n\x06\x44\x45\x44UCT\x10\x06\"\xae\x02\n\x19\x43reditTransactionsRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x11\n\tsource_id\x18\x02 \x01(\t\x12\x45\n\x10transaction_type\x18\x03 \x01(\x0e\x32+.oi.papi.credit.Transaction.TransactionType\x12\x35\n\x11min_transacted_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11max_transacted_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x18\x61lgorithm_computation_id\x18\x06 \x01(\t\"\x8d\x01\n\x1a\x43reditTransactionsResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x31\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x1b.oi.papi.credit.Transaction2\x97\x06\n\tCreditApi\x12J\n\x03\x61\x64\x64\x12 .oi.papi.credit.CreditAddRequest\x1a!.oi.papi.credit.CreditAddResponse\x12S\n\x06remove\x12#.oi.papi.credit.CreditRemoveRequest\x1a$.oi.papi.credit.CreditRemoveResponse\x12S\n\x06refund\x12#.oi.papi.credit.CreditRefundRequest\x1a$.oi.papi.credit.CreditRefundResponse\x12z\n\rset_algorithm\x12\x33.oi.papi.credit.CreditAlgorithmMultiplierSetRequest\x1a\x34.oi.papi.credit.CreditAlgorithmMultiplierSetResponse\x12~\n\x0fset_data_source\x12\x34.oi.papi.credit.CreditDataSourceMultiplierSetRequest\x1a\x35.oi.papi.credit.CreditDataSourceMultiplierSetResponse\x12Y\n\x08\x65stimate\x12%.oi.papi.credit.CreditEstimateRequest\x1a&.oi.papi.credit.CreditEstimateResponse\x12V\n\x07summary\x12$.oi.papi.credit.CreditSummaryRequest\x1a%.oi.papi.credit.CreditSummaryResponse\x12\x65\n\x0ctransactions\x12).oi.papi.credit.CreditTransactionsRequest\x1a*.oi.papi.credit.CreditTransactionsResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREDITADDREQUEST']._serialized_start=86
  _globals['_CREDITADDREQUEST']._serialized_end=155
  _globals['_CREDITADDRESPONSE']._serialized_start=157
  _globals['_CREDITADDRESPONSE']._serialized_end=197
  _globals['_CREDITREMOVEREQUEST']._serialized_start=199
  _globals['_CREDITREMOVEREQUEST']._serialized_end=271
  _globals['_CREDITREMOVERESPONSE']._serialized_start=273
  _globals['_CREDITREMOVERESPONSE']._serialized_end=316
  _globals['_CREDITREFUNDREQUEST']._serialized_start=318
  _globals['_CREDITREFUNDREQUEST']._serialized_end=390
  _globals['_CREDITREFUNDRESPONSE']._serialized_start=392
  _globals['_CREDITREFUNDRESPONSE']._serialized_end=435
  _globals['_CREDITALGORITHMMULTIPLIERSETREQUEST']._serialized_start=438
  _globals['_CREDITALGORITHMMULTIPLIERSETREQUEST']._serialized_end=571
  _globals['_CREDITALGORITHMMULTIPLIERSETRESPONSE']._serialized_start=573
  _globals['_CREDITALGORITHMMULTIPLIERSETRESPONSE']._serialized_end=632
  _globals['_CREDITDATASOURCEMULTIPLIERSETREQUEST']._serialized_start=634
  _globals['_CREDITDATASOURCEMULTIPLIERSETREQUEST']._serialized_end=723
  _globals['_CREDITDATASOURCEMULTIPLIERSETRESPONSE']._serialized_start=725
  _globals['_CREDITDATASOURCEMULTIPLIERSETRESPONSE']._serialized_end=785
  _globals['_CREDITESTIMATEREQUEST']._serialized_start=788
  _globals['_CREDITESTIMATEREQUEST']._serialized_end=1133
  _globals['_CREDITESTIMATEREQUEST_ANALYSISRESOURCES']._serialized_start=967
  _globals['_CREDITESTIMATEREQUEST_ANALYSISRESOURCES']._serialized_end=1133
  _globals['_CREDITESTIMATERESPONSE']._serialized_start=1135
  _globals['_CREDITESTIMATERESPONSE']._serialized_end=1218
  _globals['_CREDIT']._serialized_start=1220
  _globals['_CREDIT']._serialized_end=1298
  _globals['_CREDITSUMMARYREQUEST']._serialized_start=1300
  _globals['_CREDITSUMMARYREQUEST']._serialized_end=1341
  _globals['_CREDITSUMMARYRESPONSE']._serialized_start=1343
  _globals['_CREDITSUMMARYRESPONSE']._serialized_end=1427
  _globals['_TRANSACTION']._serialized_start=1430
  _globals['_TRANSACTION']._serialized_end=1880
  _globals['_TRANSACTION_TRANSACTIONTYPE']._serialized_start=1760
  _globals['_TRANSACTION_TRANSACTIONTYPE']._serialized_end=1880
  _globals['_CREDITTRANSACTIONSREQUEST']._serialized_start=1883
  _globals['_CREDITTRANSACTIONSREQUEST']._serialized_end=2185
  _globals['_CREDITTRANSACTIONSRESPONSE']._serialized_start=2188
  _globals['_CREDITTRANSACTIONSRESPONSE']._serialized_end=2329
  _globals['_CREDITAPI']._serialized_start=2332
  _globals['_CREDITAPI']._serialized_end=3123
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: algorithm_computation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61lgorithm_computation.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"\xf5\x03\n\x14\x41lgorithmComputation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x19\n\x11\x61oi_collection_id\x18\x02 \x01(\t\x12\x16\n\x0e\x61lgo_config_id\x18\x03 \x01(\t\x12\x0e\n\x06toi_id\x18\x04 \x01(\t\x12\x11\n\tinput_ids\x18\x05 \x03(\t\x12\x30\n\x0csubmitted_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x05state\x18\x07 \x01(\x0e\x32#.oi.papi.AlgorithmComputation.State\x12\x38\n\x08progress\x18\x08 \x01(\x0b\x32&.oi.papi.AlgorithmComputation.Progress\x12\x32\n\x0elast_execution\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aO\n\x08Progress\x12\x0f\n\x07running\x18\x01 \x01(\x01\x12\x11\n\tsucceeded\x18\x02 \x01(\x01\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x01\x12\x0f\n\x07no_data\x18\x04 \x01(\x01\"V\n\x05State\x12\x11\n\rUNKNOWN_STATE\x10\x00\x12\x0f\n\x0bNOT_STARTED\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\"k\n!AlgorithmComputationCreateRequest\x12\x1b\n\x13\x61lgorithm_config_id\x18\x01 \x01(\t\x12\x19\n\x11\x61oi_collection_id\x18\x02 \x01(\t\x12\x0e\n\x06toi_id\x18\x03 \x01(\t\"w\n\"AlgorithmComputationCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12<\n\x15\x61lgorithm_computation\x18\x02 \x01(\x0b\x32\x1d.oi.papi.AlgorithmComputation\"-\n\x1e\x41lgorithmComputationRunRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"6\n\x1f\x41lgorithmComputationRunResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"V\n\x1e\x41lgorithmComputationGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x9e\x01\n\x1f\x41lgorithmComputationGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12=\n\x16\x61lgorithm_computations\x18\x02 \x03(\x0b\x32\x1d.oi.papi.AlgorithmComputation\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xb2\x02\n\x1f\x41lgorithmComputationListRequest\x12\x32\n\x05state\x18\x01 \x01(\x0e\x32#.oi.papi.AlgorithmComputation.State\x12\x34\n\x10min_submitted_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10max_submitted_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13\x61lgorithm_config_id\x18\x04 \x01(\t\x12\x0e\n\x06toi_id\x18\x05 \x01(\t\x12\x19\n\x11\x61oi_collection_id\x18\x06 \x01(\t\x12\'\n\npagination\x18\x07 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x9f\x01\n AlgorithmComputationListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12=\n\x16\x61lgorithm_computations\x18\x02 \x03(\x0b\x32\x1d.oi.papi.AlgorithmComputation\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x8d\x03\n\x17\x41lgorithmComputationApi\x12\x61\n\x06\x63reate\x12*.oi.papi.AlgorithmComputationCreateRequest\x1a+.oi.papi.AlgorithmComputationCreateResponse\x12X\n\x03run\x12\'.oi.papi.AlgorithmComputationRunRequest\x1a(.oi.papi.AlgorithmComputationRunResponse\x12X\n\x03get\x12\'.oi.papi.AlgorithmComputationGetRequest\x1a(.oi.papi.AlgorithmComputationGetResponse\x12[\n\x04list\x12(.oi.papi.AlgorithmComputationListRequest\x1a).oi.papi.AlgorithmComputationListResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_computation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHMCOMPUTATION']._serialized_start=95
  _globals['_ALGORITHMCOMPUTATION']._serialized_end=596
  _globals['_ALGORITHMCOMPUTATION_PROGRESS']._serialized_start=429
  _globals['_ALGORITHMCOMPUTATION_PROGRESS']._serialized_end=508
  _globals['_ALGORITHMCOMPUTATION_STATE']._serialized_start=510
  _globals['_ALGORITHMCOMPUTATION_STATE']._serialized_end=596
  _globals['_ALGORITHMCOMPUTATIONCREATEREQUEST']._serialized_start=598
  _globals['_ALGORITHMCOMPUTATIONCREATEREQUEST']._serialized_end=705
  _globals['_ALGORITHMCOMPUTATIONCREATERESPONSE']._serialized_start=707
  _globals['_ALGORITHMCOMPUTATIONCREATERESPONSE']._serialized_end=826
  _globals['_ALGORITHMCOMPUTATIONRUNREQUEST']._serialized_start=828
  _globals['_ALGORITHMCOMPUTATIONRUNREQUEST']._serialized_end=873
  _globals['_ALGORITHMCOMPUTATIONRUNRESPONSE']._serialized_start=875
  _globals['_ALGORITHMCOMPUTATIONRUNRESPONSE']._serialized_end=929
  _globals['_ALGORITHMCOMPUTATIONGETREQUEST']._serialized_start=931
  _globals['_ALGORITHMCOMPUTATIONGETREQUEST']._serialized_end=1017
  _globals['_ALGORITHMCOMPUTATIONGETRESPONSE']._serialized_start=1020
  _globals['_ALGORITHMCOMPUTATIONGETRESPONSE']._serialized_end=1178
  _globals['_ALGORITHMCOMPUTATIONLISTREQUEST']._serialized_start=1181
  _globals['_ALGORITHMCOMPUTATIONLISTREQUEST']._serialized_end=1487
  _globals['_ALGORITHMCOMPUTATIONLISTRESPONSE']._serialized_start=1490
  _globals['_ALGORITHMCOMPUTATIONLISTRESPONSE']._serialized_end=1649
  _globals['_ALGORITHMCOMPUTATIONAPI']._serialized_start=1652
  _globals['_ALGORITHMCOMPUTATIONAPI']._serialized_end=2049
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import toi_pb2 as toi__pb2
try:
  common__models__pb2 = toi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = toi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.toi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cresult.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\ttoi.proto\"2\n\nExportFile\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_size_bytes\x18\x02 \x01(\x04\"\\\n\x11\x45xportCredentials\x12,\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x19\n\x11\x62\x61se_url_template\x18\x02 \x01(\t\"\x9d\x06\n\x06Result\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12source_aoi_version\x18\x03 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x04 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x05 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x06 \x01(\t\x12\x31\n\x0cobservations\x18\x07 \x03(\x0b\x32\x1b.oi.papi.Result.Observation\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12 \n\x18\x61lgorithm_computation_id\x18\t \x01(\t\x1a\xff\x03\n\x0bObservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_view_id\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08start_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_ts\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x05value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x06status\x18\x06 \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12=\n\x0cmeasurements\x18\x07 \x03(\x0b\x32\'.oi.papi.Result.Observation.Measurement\x12(\n\x0b\x65xport_file\x18\x08 \x01(\x0b\x32\x13.oi.papi.ExportFile\x1a\x46\n\x0bMeasurement\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\ndimensions\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0c\n\x08\x43OMPLETE\x10\x01\x12\x0b\n\x07PARTIAL\x10\x02\"\xd4\x04\n\x10ResultGetRequest\x12\x1a\n\x12source_aoi_version\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x03 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x04 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14observation_start_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x18max_observation_start_ts\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x12observation_status\x18\t \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12\x11\n\tdata_type\x18\x0b \x01(\t\x12\'\n\npagination\x18\x0c \x01(\x0b\x32\x13.oi.papi.Pagination\x12!\n\x19\x61lgorithm_computation_ids\x18\r \x03(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x0e \x03(\t\x12\x1c\n\x14include_export_files\x18\x0f \x01(\x08J\x04\x08\x01\x10\x02J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bR\x18\x61lgorithm_computation_idR\x08geom_wktR\x14include_measurements\"\xab\x01\n\x11ResultGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12 \n\x07results\x18\x03 \x03(\x0b\x32\x0f.oi.papi.Result\x12\x36\n\x12\x65xport_credentials\x18\x04 \x01(\x0b\x32\x1a.oi.papi.ExportCredentials\"\x8c\x01\n\x19ResultFilterCreateRequest\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x33\n\x12\x65xpression_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"K\n\x1aResultFilterCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10result_filter_id\x18\x02 \x01(\t\"T\n ResultFilterMappingCreateRequest\x12\x16\n\x0e\x63omputation_id\x18\x01 \x01(\t\x12\x18\n\x10result_filter_id\x18\x02 \x01(\t\"8\n!ResultFilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"V\n\x17ResultFilterListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x12\n\ndata_types\x18\x02 \x03(\t\"\x99\x01\n\x0cResultFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x33\n\x12\x65xpression_context\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdata_type\x18\x06 \x01(\t\"\x87\x01\n\x18ResultFilterListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12-\n\x0eresult_filters\x18\x02 \x03(\x0b\x32\x15.oi.papi.ResultFilter\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x95\x03\n\tResultApi\x12T\n\x03get\x12\x19.oi.papi.ResultGetRequest\x1a\x1a.oi.papi.ResultGetResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/result/get:\x01*\x12_\n\x14\x63reate_result_filter\x12\".oi.papi.ResultFilterCreateRequest\x1a#.oi.papi.ResultFilterCreateResponse\x12u\n\x1c\x63reate_result_filter_mapping\x12).oi.papi.ResultFilterMappingCreateRequest\x1a*.oi.papi.ResultFilterMappingCreateResponse\x12Z\n\x13list_result_filters\x12 .oi.papi.ResultFilterListRequest\x1a!.oi.papi.ResultFilterListResponseP\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESULTAPI'].methods_by_name['get']._loaded_options = None
  _globals['_RESULTAPI'].methods_by_name['get']._serialized_options = b'\202\323\344\223\002\020\"\013/result/get:\001*'
  _globals['_EXPORTFILE']._serialized_start=150
  _globals['_EXPORTFILE']._serialized_end=200
  _globals['_EXPORTCREDENTIALS']._serialized_start=202
  _globals['_EXPORTCREDENTIALS']._serialized_end=294
  _globals['_RESULT']._serialized_start=297
  _globals['_RESULT']._serialized_end=1094
  _globals['_RESULT_OBSERVATION']._serialized_start=583
  _globals['_RESULT_OBSERVATION']._serialized_end=1094
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_start=967
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_end=1037
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_start=1039
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_end=1094
  _globals['_RESULTGETREQUEST']._serialized_start=1097
  _globals['_RESULTGETREQUEST']._serialized_end=1693
  _globals['_RESULTGETRESPONSE']._serialized_start=1696
  _globals['_RESULTGETRESPONSE']._serialized_end=1867
  _globals['_RESULTFILTERCREATEREQUEST']._serialized_start=1870
  _globals['_RESULTFILTERCREATEREQUEST']._serialized_end=2010
  _globals['_RESULTFILTERCREATERESPONSE']._serialized_start=2012
  _globals['_RESULTFILTERCREATERESPONSE']._serialized_end=2087
  _globals['_RESULTFILTERMAPPINGCREATEREQUEST']._serialized_start=2089
  _globals['_RESULTFILTERMAPPINGCREATEREQUEST']._serialized_end=2173
  _globals['_RESULTFILTERMAPPINGCREATERESPONSE']._serialized_start=2175
  _globals['_RESULTFILTERMAPPINGCREATERESPONSE']._serialized_end=2231
  _globals['_RESULTFILTERLISTREQUEST']._serialized_start=2233
  _globals['_RESULTFILTERLISTREQUEST']._serialized_end=2319
  _globals['_RESULTFILTER']._serialized_start=2322
  _globals['_RESULTFILTER']._serialized_end=2475
  _globals['_RESULTFILTERLISTRESPONSE']._serialized_start=2478
  _globals['_RESULTFILTERLISTRESPONSE']._serialized_end=2613
  _globals['_RESULTAPI']._serialized_start=2616
  _globals['_RESULTAPI']._serialized_end=3021
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_export.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61oi_export.proto\x12\x07oi.papi\"\x9a\x01\n\x10\x41OIExportRequest\x12\x0f\n\x07\x61oi_ids\x18\x01 \x03(\t\x12-\n\tfile_type\x18\x02 \x01(\x0e\x32\x1a.oi.papi.AOIExportFileType\x12\x33\n\x0c\x61rchive_type\x18\x03 \x01(\x0e\x32\x1d.oi.papi.AOIExportArchiveType\x12\x11\n\tfile_name\x18\x04 \x01(\t\"\xae\x01\n\x1a\x41OICollectionExportRequest\x12\x19\n\x11\x61oi_collection_id\x18\x01 \x01(\t\x12-\n\tfile_type\x18\x02 \x01(\x0e\x32\x1a.oi.papi.AOIExportFileType\x12\x33\n\x0c\x61rchive_type\x18\x03 \x01(\x0e\x32\x1d.oi.papi.AOIExportArchiveType\x12\x11\n\tfile_name\x18\x04 \x01(\t\"%\n\x11\x41OIExportResponse\x12\x10\n\x08location\x18\x01 \x01(\t\"/\n\x1b\x41OICollectionExportResponse\x12\x10\n\x08location\x18\x01 \x01(\t*a\n\x11\x41OIExportFileType\x12\x1b\n\x17UNKNOWN_EXPORT_FILETYPE\x10\x00\x12\x0b\n\x07GEOJSON\x10\x01\x12\x12\n\x0e\x45SRI_SHAPEFILE\x10\x02\x12\x0e\n\nGEOPACKAGE\x10\x03*>\n\x14\x41OIExportArchiveType\x12\x18\n\x14UNKNOWN_ARCHIVE_TYPE\x10\x00\x12\x0c\n\x08ZIP_FILE\x10\x01\x32\xb4\x01\n\x0c\x41OIExportApi\x12\x44\n\x0b\x65xport_aois\x12\x19.oi.papi.AOIExportRequest\x1a\x1a.oi.papi.AOIExportResponse\x12^\n\x11\x65xport_collection\x12#.oi.papi.AOICollectionExportRequest\x1a$.oi.papi.AOICollectionExportResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_export_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AOIEXPORTFILETYPE']._serialized_start=451
  _globals['_AOIEXPORTFILETYPE']._serialized_end=548
  _globals['_AOIEXPORTARCHIVETYPE']._serialized_start=550
  _globals['_AOIEXPORTARCHIVETYPE']._serialized_end=612
  _globals['_AOIEXPORTREQUEST']._serialized_start=30
  _globals['_AOIEXPORTREQUEST']._serialized_end=184
  _globals['_AOICOLLECTIONEXPORTREQUEST']._serialized_start=187
  _globals['_AOICOLLECTIONEXPORTREQUEST']._serialized_end=361
  _globals['_AOIEXPORTRESPONSE']._serialized_start=363
  _globals['_AOIEXPORTRESPONSE']._serialized_end=400
  _globals['_AOICOLLECTIONEXPORTRESPONSE']._serialized_start=402
  _globals['_AOICOLLECTIONEXPORTRESPONSE']._serialized_end=449
  _globals['_AOIEXPORTAPI']._serialized_start=615
  _globals['_AOIEXPORTAPI']._serialized_end=795
# @@protoc_insertion_point(module_scope)



import common_models_pb2 as _common_models_pb2
import analysis_config_pb2 as _analysis_config_pb2
import common_models_pb2 as _common_models_pb2_1
import analysis_pb2 as _analysis_pb2
import analysis_version_pb2 as _analysis_version_pb2
import algorithm_config_pb2 as _algorithm_config_pb2
import analysis_computation_pb2 as _analysis_computation_pb2
import common_models_pb2 as _common_models_pb2_1_1
import analysis_pb2 as _analysis_pb2_1
import aoi_collection_pb2 as _aoi_collection_pb2
import common_models_pb2 as _common_models_pb2_1_1_1
import result_pb2 as _result_pb2
import common_models_pb2 as _common_models_pb2_1_1_1_1
import toi_pb2 as _toi_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional
from common_models_pb2 import Pagination as Pagination
from analysis_config_pb2 import AnalysisConfig as AnalysisConfig
from analysis_config_pb2 import AnalysisConfigCreateRequest as AnalysisConfigCreateRequest
from analysis_config_pb2 import AnalysisConfigCreateResponse as AnalysisConfigCreateResponse
from analysis_config_pb2 import AnalysisConfigUpdateRequest as AnalysisConfigUpdateRequest
from analysis_config_pb2 import AnalysisConfigUpdateResponse as AnalysisConfigUpdateResponse
from analysis_config_pb2 import AnalysisConfigGetRequest as AnalysisConfigGetRequest
from analysis_config_pb2 import AnalysisConfigGetResponse as AnalysisConfigGetResponse
from analysis_config_pb2 import AnalysisConfigListRequest as AnalysisConfigListRequest
from analysis_config_pb2 import AnalysisConfigListResponse as AnalysisConfigListResponse
from analysis_config_pb2 import AnalysisConfigDeactivateRequest as AnalysisConfigDeactivateRequest
from analysis_config_pb2 import AnalysisConfigDeactivateResponse as AnalysisConfigDeactivateResponse
from analysis_computation_pb2 import AnalysisComputationCreateRequest as AnalysisComputationCreateRequest
from analysis_computation_pb2 import AnalysisComputationCreateResponse as AnalysisComputationCreateResponse
from analysis_computation_pb2 import AnalysisComputationRunRequest as AnalysisComputationRunRequest
from analysis_computation_pb2 import AnalysisComputationRunResponse as AnalysisComputationRunResponse
from analysis_computation_pb2 import AnalysisComputationGetRequest as AnalysisComputationGetRequest
from analysis_computation_pb2 import AnalysisComputationNode as AnalysisComputationNode
from analysis_computation_pb2 import AnalysisComputation as AnalysisComputation
from analysis_computation_pb2 import AnalysisComputationGetResponse as AnalysisComputationGetResponse
from analysis_computation_pb2 import AnalysisComputationListRequest as AnalysisComputationListRequest
from analysis_computation_pb2 import AnalysisComputationListResponse as AnalysisComputationListResponse
from aoi_collection_pb2 import AOICollection as AOICollection
from aoi_collection_pb2 import AOIInfo as AOIInfo
from aoi_collection_pb2 import AOICollectionCreateRequest as AOICollectionCreateRequest
from aoi_collection_pb2 import AOICollectionCreateResponse as AOICollectionCreateResponse
from aoi_collection_pb2 import AOICollectionGetRequest as AOICollectionGetRequest
from aoi_collection_pb2 import AOICollectionGetResponse as AOICollectionGetResponse
from aoi_collection_pb2 import AOICollectionAddRequest as AOICollectionAddRequest
from aoi_collection_pb2 import AOICollectionAddResponse as AOICollectionAddResponse
from aoi_collection_pb2 import AOICollectionRemoveRequest as AOICollectionRemoveRequest
from aoi_collection_pb2 import AOICollectionRemoveResponse as AOICollectionRemoveResponse
from aoi_collection_pb2 import AOICollectionCloneRequest as AOICollectionCloneRequest
from aoi_collection_pb2 import AOICollectionCloneResponse as AOICollectionCloneResponse
from aoi_collection_pb2 import AOICollectionListRequest as AOICollectionListRequest
from aoi_collection_pb2 import AOICollectionListResponse as AOICollectionListResponse
from result_pb2 import ExportFile as ExportFile
from result_pb2 import ExportCredentials as ExportCredentials
from result_pb2 import Result as Result
from result_pb2 import ResultGetRequest as ResultGetRequest
from result_pb2 import ResultGetResponse as ResultGetResponse
from result_pb2 import ResultFilterCreateRequest as ResultFilterCreateRequest
from result_pb2 import ResultFilterCreateResponse as ResultFilterCreateResponse
from result_pb2 import ResultFilterMappingCreateRequest as ResultFilterMappingCreateRequest
from result_pb2 import ResultFilterMappingCreateResponse as ResultFilterMappingCreateResponse
from result_pb2 import ResultFilterListRequest as ResultFilterListRequest
from result_pb2 import ResultFilter as ResultFilter
from result_pb2 import ResultFilterListResponse as ResultFilterListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectAnalysisConfigUpdateRequest(_message.Message):
    __slots__ = ("project_id", "analysis_config_ids")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_IDS_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    analysis_config_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, project_id: _Optional[str] = ..., analysis_config_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectAnalysisConfigUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import aoi_catalog_pb2 as aoi__catalog__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in aoi_catalog_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class AOICatalogApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_aoi_stats = channel.unary_unary(
                '/oi.papi.AOICatalogApi/get_aoi_stats',
                request_serializer=aoi__catalog__pb2.AOIStatsGetRequest.SerializeToString,
                response_deserializer=aoi__catalog__pb2.AOIStatsGetResponse.FromString,
                _registered_method=True)
        self.get_aoi_clusters = channel.unary_unary(
                '/oi.papi.AOICatalogApi/get_aoi_clusters',
                request_serializer=aoi__catalog__pb2.AOIClusterGetRequest.SerializeToString,
                response_deserializer=aoi__catalog__pb2.AOIClusterGetResponse.FromString,
                _registered_method=True)
        self.add_aoi_to_catalog = channel.unary_unary(
                '/oi.papi.AOICatalogApi/add_aoi_to_catalog',
                request_serializer=aoi__catalog__pb2.AOICatalogAddRequest.SerializeToString,
                response_deserializer=aoi__catalog__pb2.AOICatalogAddResponse.FromString,
                _registered_method=True)
        self.delete_aoi_from_catalog = channel.unary_unary(
                '/oi.papi.AOICatalogApi/delete_aoi_from_catalog',
                request_serializer=aoi__catalog__pb2.AOICatalogDeleteRequest.SerializeToString,
                response_deserializer=aoi__catalog__pb2.AOICatalogDeleteResponse.FromString,
                _registered_method=True)
        self.get_private_catalog_collection = channel.unary_unary(
                '/oi.papi.AOICatalogApi/get_private_catalog_collection',
                request_serializer=aoi__catalog__pb2.AOICatalogGetPrivateCatalogRequest.SerializeToString,
                response_deserializer=aoi__catalog__pb2.AOICatalogGetPrivateCatalogResponse.FromString,
                _registered_method=True)


class AOICatalogApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get_aoi_stats(self, request, context):
        """
        Get the clustered counts of AOIs at different points across the provided bounding box.
        The algorithm determining the lat,long at which the clusters converge is purely controlled by the server.
        Please use help endpoint for more info on the filters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_aoi_clusters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_aoi_to_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_aoi_from_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_private_catalog_collection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AOICatalogApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_aoi_stats': grpc.unary_unary_rpc_method_handler(
                    servicer.get_aoi_stats,
                    request_deserializer=aoi__catalog__pb2.AOIStatsGetRequest.FromString,
                    response_serializer=aoi__catalog__pb2.AOIStatsGetResponse.SerializeToString,
            ),
            'get_aoi_clusters': grpc.unary_unary_rpc_method_handler(
                    servicer.get_aoi_clusters,
                    request_deserializer=aoi__catalog__pb2.AOIClusterGetRequest.FromString,
                    response_serializer=aoi__catalog__pb2.AOIClusterGetResponse.SerializeToString,
            ),
            'add_aoi_to_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.add_aoi_to_catalog,
                    request_deserializer=aoi__catalog__pb2.AOICatalogAddRequest.FromString,
                    response_serializer=aoi__catalog__pb2.AOICatalogAddResponse.SerializeToString,
            ),
            'delete_aoi_from_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_aoi_from_catalog,
                    request_deserializer=aoi__catalog__pb2.AOICatalogDeleteRequest.FromString,
                    response_serializer=aoi__catalog__pb2.AOICatalogDeleteResponse.SerializeToString,
            ),
            'get_private_catalog_collection': grpc.unary_unary_rpc_method_handler(
                    servicer.get_private_catalog_collection,
                    request_deserializer=aoi__catalog__pb2.AOICatalogGetPrivateCatalogRequest.FromString,
                    response_serializer=aoi__catalog__pb2.AOICatalogGetPrivateCatalogResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AOICatalogApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AOICatalogApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AOICatalogApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get_aoi_stats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOICatalogApi/get_aoi_stats',
            aoi__catalog__pb2.AOIStatsGetRequest.SerializeToString,
            aoi__catalog__pb2.AOIStatsGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_aoi_clusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOICatalogApi/get_aoi_clusters',
            aoi__catalog__pb2.AOIClusterGetRequest.SerializeToString,
            aoi__catalog__pb2.AOIClusterGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def add_aoi_to_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOICatalogApi/add_aoi_to_catalog',
            aoi__catalog__pb2.AOICatalogAddRequest.SerializeToString,
            aoi__catalog__pb2.AOICatalogAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete_aoi_from_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOICatalogApi/delete_aoi_from_catalog',
            aoi__catalog__pb2.AOICatalogDeleteRequest.SerializeToString,
            aoi__catalog__pb2.AOICatalogDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_private_catalog_collection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AOICatalogApi/get_private_catalog_collection',
            aoi__catalog__pb2.AOICatalogGetPrivateCatalogRequest.SerializeToString,
            aoi__catalog__pb2.AOICatalogGetPrivateCatalogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: algorithm.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61lgorithm.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"{\n\tAlgorithm\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12.\n\ncreated_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x16\x41lgorithmCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\"U\n\x17\x41lgorithmCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\talgorithm\x18\x02 \x01(\x0b\x32\x12.oi.papi.Algorithm\"K\n\x13\x41lgorithmGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"|\n\x14\x41lgorithmGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\nalgorithms\x18\x02 \x03(\x0b\x32\x12.oi.papi.Algorithm\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xbc\x01\n\x14\x41lgorithmListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x32\n\x0emin_created_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\npagination\x18\x04 \x01(\x0b\x32\x13.oi.papi.Pagination\"}\n\x15\x41lgorithmListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\nalgorithms\x18\x02 \x03(\x0b\x32\x12.oi.papi.Algorithm\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"@\n\x16\x41lgorithmUpdateRequest\x12&\n\nalgorithms\x18\x01 \x03(\x0b\x32\x12.oi.papi.Algorithm\".\n\x17\x41lgorithmUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xb3\x02\n\x0c\x41lgorithmApi\x12K\n\x06\x63reate\x12\x1f.oi.papi.AlgorithmCreateRequest\x1a .oi.papi.AlgorithmCreateResponse\x12K\n\x06update\x12\x1f.oi.papi.AlgorithmUpdateRequest\x1a .oi.papi.AlgorithmUpdateResponse\x12\x42\n\x03get\x12\x1c.oi.papi.AlgorithmGetRequest\x1a\x1d.oi.papi.AlgorithmGetResponse\x12\x45\n\x04list\x12\x1d.oi.papi.AlgorithmListRequest\x1a\x1e.oi.papi.AlgorithmListResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHM']._serialized_start=82
  _globals['_ALGORITHM']._serialized_end=205
  _globals['_ALGORITHMCREATEREQUEST']._serialized_start=207
  _globals['_ALGORITHMCREATEREQUEST']._serialized_end=283
  _globals['_ALGORITHMCREATERESPONSE']._serialized_start=285
  _globals['_ALGORITHMCREATERESPONSE']._serialized_end=370
  _globals['_ALGORITHMGETREQUEST']._serialized_start=372
  _globals['_ALGORITHMGETREQUEST']._serialized_end=447
  _globals['_ALGORITHMGETRESPONSE']._serialized_start=449
  _globals['_ALGORITHMGETRESPONSE']._serialized_end=573
  _globals['_ALGORITHMLISTREQUEST']._serialized_start=576
  _globals['_ALGORITHMLISTREQUEST']._serialized_end=764
  _globals['_ALGORITHMLISTRESPONSE']._serialized_start=766
  _globals['_ALGORITHMLISTRESPONSE']._serialized_end=891
  _globals['_ALGORITHMUPDATEREQUEST']._serialized_start=893
  _globals['_ALGORITHMUPDATEREQUEST']._serialized_end=957
  _globals['_ALGORITHMUPDATERESPONSE']._serialized_start=959
  _globals['_ALGORITHMUPDATERESPONSE']._serialized_end=1005
  _globals['_ALGORITHMAPI']._serialized_start=1008
  _globals['_ALGORITHMAPI']._serialized_end=1315
# @@protoc_insertion_point(module_scope)
